package Ogre::QueuedRenderableCollection;

use strict;
use warnings;


########## GENERATED CONSTANTS BEGIN
require Exporter;
unshift @Ogre::QueuedRenderableCollection::ISA, 'Exporter';

our %EXPORT_TAGS = (
	'OrganisationMode' => [qw(
		OM_PASS_GROUP
		OM_SORT_DESCENDING
		OM_SORT_ASCENDING
	)],
);

$EXPORT_TAGS{'all'} = [ map { @{ $EXPORT_TAGS{$_} } } keys %EXPORT_TAGS ];
our @EXPORT_OK = @{ $EXPORT_TAGS{'all'} };
our @EXPORT = ();
########## GENERATED CONSTANTS END
1;

__END__
