package Ogre::AnimationControllerFunction;

use strict;
use warnings;

# N.B. although this inherits from Ogre::ControllerFunction<Real>,
# that doesn't happen here,
# and you must not do that in your code, either.


1;

__END__
