package Ogre::IntersectionSceneQuery;

use strict;
use warnings;

use Ogre::SceneQuery;
# use Ogre::IntersectionSceneQueryListener;
our @ISA = qw(Ogre::SceneQuery);  # Ogre::IntersectionSceneQueryListener


1;

__END__
