package Ogre::FrameEvent;

use strict;
use warnings;


1;

__END__
=head1 NAME

Ogre::FrameEvent

=head1 SYNOPSIS

  use Ogre;
  use Ogre::FrameEvent;
  # (for now see examples/README.txt)

=head1 DESCRIPTION

See the online API documentation at
 L<http://www.ogre3d.org/docs/api/html/classOgre_1_1FrameEvent.html>

B<Note:> this Perl binding is currently I<experimental> and subject to API changes.

=head1 INSTANCE METHODS

=head2 $obj->timeSinceLastEvent()

I<Returns>

=over

=item Real

=back

=head2 $obj->timeSinceLastFrame()

I<Returns>

=over

=item Real

=back

=head1 AUTHOR

Scott Lanning E<lt>slanning@cpan.orgE<gt>

For licensing information, see README.txt .

=cut
