package Ogre::RibbonTrail;

use strict;
use warnings;

use Ogre::RenderTarget;
our @ISA = qw(Ogre::BillboardChain);   # Ogre::Node::Listener


1;

__END__
=head1 NAME

Ogre::RibbonTrail

=head1 SYNOPSIS

  use Ogre;
  use Ogre::RibbonTrail;
  # (for now see examples/README.txt)

=head1 DESCRIPTION

See the online API documentation at
 L<http://www.ogre3d.org/docs/api/html/classOgre_1_1RibbonTrail.html>

B<Note:> this Perl binding is currently I<experimental> and subject to API changes.

=head1 AUTHOR

Scott Lanning E<lt>slanning@cpan.orgE<gt>

For licensing information, see README.txt .

=cut
